colour.plotting.characterisation Module — Colour 0.3.0 documentation

# colour.plotting.characterisation Module

## Characterisation Plotting

Defines the characterisation plotting objects:

- `colour_checker_plot()`

`colour.plotting.characterisation.` `colour_checker_plot`(colour_checker='ColorChecker 2005', **kwargs)

  Plots given colour checker.

  Parameters: | colour_checker (unicode, optional) – Color checker name. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool
  Raises: | `KeyError` – If the given colour rendition chart is not found in the factory colour rendition charts.

  Examples

      >>> colour_checker_plot()
      True